# Lite YouTube Module

## Overview
Lite YouTube is a Drupal module that provides an alternative field formatter for rendering YouTube fields using JavaScript libraries instead of the default OEmbed iframe. This approach is designed to improve performance and user experience.

## Features
- Custom field formatter for YouTube fields.
- Renders videos using lightweight JavaScript libraries.
- Enhances performance compared to the default OEmbed iframe rendering.

## Installation
Install as you would normally install a contributed Drupal module. For further information, see [Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-modules).

## Usage
This module extends the functionality provided by the YouTube module. It leverages the capability to handle various YouTube URL formats, including:

- `http://youtube.com/watch?v=[video_id]`
- `http://youtu.be/[video_id]`
- `http://youtube.com/v/[video_id]`
- `http://youtube.com/embed/[video_id]`
- `http://youtube.com/?v=[video_id]`

The above formats are accepted with or without `http://`, with `www.`, or with `https://` instead of `http://`. Additionally, parameters appended to the URL are ignored, and `v` does not need to be the first parameter.

Lite YouTube builds upon this foundation to provide a lightweight, JavaScript-based rendering option, offering improved performance and customization options.

### Configuration
1. Create a new field for YouTube videos in your desired content type.
2. Go to the display configuration page or block for your content type:
   - **Structure > Content types > [Your content type] > Manage display.**
3. Change the field formatter for the corresponding field to "Lite YouTube."
4. Configure the specific formatter options via the field's settings button:
   - **Play Button Title**: Text for the button to play the video.
   - **Poster Quality**: Select thumbnail quality (HQ, SD, etc.).
   - **Poster Loading**: Configure lazy loading for thumbnails.
   - **Use nocookie**: Enable the use of the YouTube nocookie URL.
   - **Autoload**: Enable automatic video loading on scroll.
   - **Short**: Display YouTube Shorts-style videos on mobile devices.
   - **Custom Parameters**: Add additional parameters to the video URL. Use any [YouTube Embedded Players and Player Parameters](https://developers.google.com/youtube/player_parameters?hl=es-419). Note: the exception to this rule is the autoplay param; because of the nature of the performance loading and the inconsistency of usage, that parameter generally does not work.

## Dependencies
The module depends on the following:

### Contributed module:
- **YouTube module**

Ensure these modules are installed and enabled for the `lite_youtube` module to function correctly.
