<?php

namespace Drupal\lite_youtube\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines the settings form for the Lite YouTube module.
 *
 * This form allows administrators to configure the external JavaScript
 * URL used to load the lite-youtube.js library .
 */
class LiteYoutubeSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'lite_youtube_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['lite_youtube.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('lite_youtube.settings');

    $stored_url = $config->get('live_youtube_js_url') ?? 'https://cdn.jsdelivr.net/npm/@justinribeiro/lite-youtube@latest/lite-youtube.js';
    $form['live_youtube_js_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('JS URL for lite-youtube.js'),
      '#description' => $this->t('External URL of the lite-youtube JavaScript library (type: module). Leave empty to use default.'),
      '#default_value' => $stored_url,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('lite_youtube.settings')
      ->set('live_youtube_js_url', $form_state->getValue('live_youtube_js_url'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
